Appellate Division, First Department, Decisions

Home > Decisions
Home Decisions Advanced Search Style Manual Research Citation Services

Archives

July, 2015
Cases Decided July 28, 2015
Title | Judge | Docket No. | Slip Opinion No.
Ganaj v New York City Health & Hosps. Corp. |  | 15072 303203/08 | 2015 NY Slip Op 06294
Noor v City of New York |  | 15080 102899/07 | 2015 NY Slip Op 06295
Tower Ins. Co. of N.Y. v Brown |  | 15339 153797/12 | 2015 NY Slip Op 06296
Garrison Special Opportunities Fund LP v Fidelity Natl. Card Servs., Inc. |  | 15140 603081/08 | 2015 NY Slip Op 06297
Amacio v State of New York |  | 98546 | 2015 NY Slip Op 06298
Lee v Woori Bank | Tom, J.P. | 154157/14 14872 | 2015 NY Slip Op 06299
Matter of Rosabianca | Per Curiam | M-1874 | 2015 NY Slip Op 06300
Matter of Teague | Per Curiam | M-1137 | 2015 NY Slip Op 06301
Cases Decided July 21, 2015
Title | Judge | Docket No. | Slip Opinion No.
U.S. Bank, N.A. v Landman |  | 13455 381515/08 | 2015 NY Slip Op 06194
Smoke v Windemere Owners LLC |  | 15471 113051/11 | 2015 NY Slip Op 06195
Chekowsky v Windemere Owners, LLC |  | 106532/11 15473 15472 | 2015 NY Slip Op 06196
Dreisinger v Teglasi |  | 14989 308023/10 | 2015 NY Slip Op 06197
MMA Meadows at Green Tree, LLC v Millrun Apts., LLC |  | 653943/13 15381 15380 | 2015 NY Slip Op 06198
People v Maxwell |  | 15575 1751/10 | 2015 NY Slip Op 06199
For The People Theaters of N.Y. Inc. v City of New York | Kapnick, J. | 121197/02 121080/02 12158 | 2015 NY Slip Op 06200
381 Search Warrants Directed to Facebook, Inc. v New York County Dist. Attorney's Off. | Renwick, J. | 30207/13 30178/14 | 2015 NY Slip Op 06201
Cases Decided July 14, 2015
Title | Judge | Docket No. | Slip Opinion No.
Matter of Kusyk v New York City Dept. of Bldgs. |  | 112036/11 13165 13164 | 2015 NY Slip Op 06088
Saunders v Guberman |  | 350015/12 13897N 13896N | 2015 NY Slip Op 06089
Silver v Whitney Partners LLC |  | 14029 100020/13 | 2015 NY Slip Op 06090
Greenman-Pedersen, Inc. v Berryman & Henigar, Inc. |  | 14062 403085/09 | 2015 NY Slip Op 06091
People v Gutierrez |  | 14291 1381/09 | 2015 NY Slip Op 06092
People v Sanders |  | 3679/11 15182 722/12 15181 | 2015 NY Slip Op 06093
Gansevoort 69 Realty LLC v Laba |  | 15196 651010/13 | 2015 NY Slip Op 06094
Nash v Port Auth. of N.Y. & N.J. | Manzanet-Daniels | 129074/93 15032 | 2015 NY Slip Op 06095
Matter of Ehrenfeld | Per Curiam | M-1822 | 2015 NY Slip Op 06096
Matter of Gilbert | Per Curiam | M-6361 | 2015 NY Slip Op 06097
Matter of Verzani | Per Curiam | M-286 | 2015 NY Slip Op 06098
Cases Decided July 9, 2015
Title | Judge | Docket No. | Slip Opinion No.
Matter of Kotick v Shvachko |  | 15074 1202/05 | 2015 NY Slip Op 06011
Duckett v New York Presbyt. Hosp. |  | 15623 114004/10 | 2015 NY Slip Op 06012
People v Montero |  | 15657 4921/11 | 2015 NY Slip Op 06013
Castlepoint Ins. Co. v Hilmand Realty, LLC |  | 15658 156301/12 | 2015 NY Slip Op 06014
Michels v Marton |  | 15659 110644/11 | 2015 NY Slip Op 06015
Hoffman v Biltmore 47 Assoc., LLC |  | 108095/06 -591083/07 -590494/09 15662A 590052/13 590059/13 15662 15661 15660 | 2015 NY Slip Op 06016
People v Olivero |  | 15663 6306/10 | 2015 NY Slip Op 06017
People v Nashal |  | 15665 1687/13 | 2015 NY Slip Op 06018
Gabriel v Board of Mgrs. of the Gallery House Condominium |  | 151715/14 15667 15666 | 2015 NY Slip Op 06019
Lynn & Cahill LLP v Witkin |  | 15668 114676/09 | 2015 NY Slip Op 06020
People v Delgado |  | 15669 2491/11 | 2015 NY Slip Op 06021
Luis S. v City of New York |  | 15670 350045/08 | 2015 NY Slip Op 06022
Cangro v Reitano |  | 15671 100381/13 | 2015 NY Slip Op 06023
People v Sanford |  | 15672 30149/13 | 2015 NY Slip Op 06024
Levin v Mercedes-Benz Manhattan, Inc. |  | 15673 108182/11 590791/12 590624/13 | 2015 NY Slip Op 06025
People v Rivera |  | 15674 1541/12 | 2015 NY Slip Op 06026
Matter of New York City Asbestos Litig. |  | 40000/88 -190215/11 -190262/11 15678 190293/11 190294/11 190299/11 190311/11 15677 15676 15675 | 2015 NY Slip Op 06027
Forty Cent. Park S., Inc. v Anza |  | 651841/13 15680N 15679 | 2015 NY Slip Op 06028
Russo v Rozenholc |  | 14208 650457/12 | 2015 NY Slip Op 06029
Estee Lauder Inc. v OneBeacon Ins. Group, LLC |  | 15549N 602379/05 | 2015 NY Slip Op 06030
People v Williams |  | 15681 584/11 | 2015 NY Slip Op 06031
Garcia v Feigelson |  | 15682 104032/10 | 2015 NY Slip Op 06032
People v Slater |  | 15684 2261/12 | 2015 NY Slip Op 06033
Barry v Pepsi-Cola Bottling Co. of N.Y., Inc. |  | 15685 309625/12 | 2015 NY Slip Op 06034
Littlejohn v Dominos Pizza LLC |  | 111186/11 15688A 15688 | 2015 NY Slip Op 06035
Johnson v Salaj |  | 15689 304975/11 | 2015 NY Slip Op 06036
People v Batista |  | 4230/07 15690A 3650/08 15690 | 2015 NY Slip Op 06037
People v Cruz |  | 15691 602/07 | 2015 NY Slip Op 06038
People v Tate |  | 15692 4129/08 | 2015 NY Slip Op 06039
Gem Holdco, LLC v Ridgeline Energy Servs., Inc. |  | 15694N 650841/13 | 2015 NY Slip Op 06040
Transport Workers Union of Greater N.Y. v Bianco |  | 15696 652798/13 | 2015 NY Slip Op 06041
Matter of New York City Tr. Auth. v Transport Workers Union of Greater N.Y. Local 100 |  | 15697N 451546/14 | 2015 NY Slip Op 06042
Matter of Sanders v Newbauer |  | 15698 652/15 | 2015 NY Slip Op 06043
Medinas v MILT Holdings LLC | Saxe, J. | 590701/11 101003/11 15423 | 2015 NY Slip Op 06044
Matter of Cumberbatch | Per Curiam | M-2036 | 2015 NY Slip Op 06045
Matter of Fisher | Per Curiam | M-310 M-5318 | 2015 NY Slip Op 06046
Matter of Nachamie v Curiam | Per Curiam | M-2222 | 2015 NY Slip Op 06047
Cases Decided July 7, 2015
Title | Judge | Docket No. | Slip Opinion No.
Matter of Jahmeka W. |  | 15618 | 2015 NY Slip Op 05876
Wyle Inc. v ITT Corp. |  | 14107 653465/11 | 2015 NY Slip Op 05877
Progressive Realty Assoc., L.P. v White |  | 15097 151260/14 | 2015 NY Slip Op 05878
Aziz v City of New York |  | 23810/04 15378 15377 | 2015 NY Slip Op 05879
Matter of Ansonia Assoc. L.P. v Unwin |  | 15531 570033/14 50451/12 | 2015 NY Slip Op 05880
People v Johnson |  | 15628 3799/72 4532/72 | 2015 NY Slip Op 05881
Davis v Nyack Hosp. |  | 15629 106956/08 | 2015 NY Slip Op 05882
Matter of Imani G. (Pedro G.) |  | 15632 15631 15630 | 2015 NY Slip Op 05883
People v Wells |  | 6548/06 -41/07 - 15635 15634 15633 | 2015 NY Slip Op 05884
Matter of Carlos L. v Diomaris C. |  | 15636 | 2015 NY Slip Op 05885
El-Ad 250 W. LLC v Zurich Am. Ins. Co. |  | 15637 652964/13 | 2015 NY Slip Op 05886
Matter of Richter v Cardozo |  | 15638 101447/13 | 2015 NY Slip Op 05887
People v Timmons |  | 15639 6818/03 | 2015 NY Slip Op 05888
Jackson v Whitson's Food Corp. |  | 303448/10 15640A 15640 | 2015 NY Slip Op 05889
People v Lara |  | 5117/08 15643 15642 | 2015 NY Slip Op 05890
Liberty Mut. Ins. Co. v Five Boro Med. Equip., Inc. |  | 15644 | 2015 NY Slip Op 05891
LAIG v Medanito S.A. |  | 15645 160103/14 | 2015 NY Slip Op 05892
Ward v Ruppert Hous. Co., Inc. |  | 15646 115058/10 | 2015 NY Slip Op 05893
People v Pannizzo |  | 15647 36054/12 | 2015 NY Slip Op 05894
Carey & Assoc. LLC v 521 Fifth Ave. Partners, LLC |  | 15648 650165/08 | 2015 NY Slip Op 05895
Lipin v Danske Bank |  | 155308/13 -100807/13 ---15652NB 15652NA 15652N 15651N 15650N 15649N | 2015 NY Slip Op 05896
Matter of Metropolitan Transp. Auth. |  | 401189/08 -401190/08 15655N 401191/08 15654N 15653N | 2015 NY Slip Op 05897
People v Paulino | Degrasse, J. | 1727/08 14168 | 2015 NY Slip Op 05898
Cases Decided July 2, 2015
Title | Judge | Docket No. | Slip Opinion No.
People v Algarin |  | 15600 4335/12 | 2015 NY Slip Op 05755
Vogel v Martos Dev., LLC |  | 15601 310447/11 | 2015 NY Slip Op 05756
Matter of Jalicia G. (Jacqueline G.) |  | 15606 15605 15604 15603 15602 | 2015 NY Slip Op 05757
Valji v Valji |  | 15607 311566/14 | 2015 NY Slip Op 05758
Matter of Rhames v City of New York |  | 15608 308813/12 | 2015 NY Slip Op 05759
Structure Tone, Inc. v National Cas. Co. |  | 154651/12 15610 15609 | 2015 NY Slip Op 05760
People v Stewart-Hemphil |  | 15611 5137/11 | 2015 NY Slip Op 05761
Knopf v Sanford |  | 15613 113227/09 15074/11 | 2015 NY Slip Op 05762
Mergent Servs. v ITEX Corp. |  | 15616 601777/07 | 2015 NY Slip Op 05763
People v Covington |  | 15617 5715/10 | 2015 NY Slip Op 05764
Yannetti v Hammerstein Ballroom |  | 109955/09 15619A 15619 | 2015 NY Slip Op 05765
People v Smith |  | 15620 2163/13 | 2015 NY Slip Op 05766
Andejo Corp. v South St. Seaport Ltd. Partnership |  | 15621 603707/04 | 2015 NY Slip Op 05767
People v Cuenea |  | 15622 4140N/11 | 2015 NY Slip Op 05768
Duckett v New York Presbyt. Hosp. |  | 15623 114004/10 | 2015 NY Slip Op 05769
Lau v Lazar |  | 15626 651648/13 | 2015 NY Slip Op 05770
Domingez v Zinnar |  | 15627N 116709/06 | 2015 NY Slip Op 05771
Overseas Shipholding Group, Inc. v Proskauer Rose, LLP |  | 650765/14 14412A 14412 | 2015 NY Slip Op 05772
Matter of Ephraim |  | 14676 4109/06 | 2015 NY Slip Op 05773
Matter of 12-14 E. 64th Owners Corp. v Hixon |  | 14924 570432/11 | 2015 NY Slip Op 05774
People v Hawkins |  | 15578 1633/07 | 2015 NY Slip Op 05775
Smith v New York City Hous. Auth. |  | 15579 6417/05 | 2015 NY Slip Op 05776
Matter of Jake M. |  | 15580 | 2015 NY Slip Op 05777
Forbes v Giacomo |  | 157640/12 15582 15581 | 2015 NY Slip Op 05778
Santiago v New York City Dept. of Educ. |  | 103976/12 15584 15583 | 2015 NY Slip Op 05779
Kohan v Nehmadi |  | 15585 104185/11 | 2015 NY Slip Op 05780
People v Rutledge |  | 15586 2903/13 | 2015 NY Slip Op 05781
Guzman v Broadway 922 Enters., LLC |  | 15587 305778/11 | 2015 NY Slip Op 05782
Oduro v Bronxdale Outer, Inc. |  | 15588 300992/12 | 2015 NY Slip Op 05783
Matter of Williams v New York City Hous. Auth. |  | 15589 100189/14 | 2015 NY Slip Op 05784
Matter of Merkin v Berman |  | 15590 652415/12 | 2015 NY Slip Op 05785
People v Colon |  | 15591 3094/11 | 2015 NY Slip Op 05786
Matter of Haubenstock v City of New York |  | 15592 651892/13 | 2015 NY Slip Op 05787
People v Johnson |  | 15594 4759/12 | 2015 NY Slip Op 05788
Rivera v Victoria's Secret Stores, LLC |  | 15596 155874/12 | 2015 NY Slip Op 05789
Matter of Avella v City of New York | Mazzarelli, J.p. | 100161/14 15026 | 2015 NY Slip Op 05790
Home | Contents | Site Search | Publications | Decisions | Decision Search Citation Services | Archives | Style Manual | Legal Research Portal New York State Law Reporting Bureau 17 Lodge Street, Albany, NY 12207 phone: (518) 453-6900 fax: (518) 426-1640